@@ -1,20 +1,26 @@
+from botty_core import CompositeHandler, app
+
 from .buttons import CallbackButton, UrlButton
 from .handlers import (
     CommandHandler,
-    CompositeHandler,
     InlineMenuHandler,
     MessageHandler,
     QueryHandler,
+    StartGroupHandler,
     StartHandler,
     TextHandler,
     UpdateHandler,
 )
 from .keyboards import InlineButtons, InlineKeyboard
-from .loader import app
 from .texts import Texts
 
 __all__ = [
     "app",
+    "Texts",
+    "InlineButtons",
+    "InlineKeyboard",
+    "UrlButton",
+    "CallbackButton",
     "CompositeHandler",
     "UpdateHandler",
     "MessageHandler",
@@ -22,10 +28,6 @@ __all__ = [
     "TextHandler",
     "CommandHandler",
     "StartHandler",
+    "StartGroupHandler",
     "InlineMenuHandler",
-    "CallbackButton",
-    "UrlButton",
-    "InlineKeyboard",
-    "InlineButtons",
-    "Texts",
 ]
